# PyTorch 书

[![GitHub issues](https://img.shields.io/github/issues/xinetzone/pytorch-book)](https://github.com/xinetzone/pytorch-book/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/pytorch-book)](https://github.com/xinetzone/pytorch-book/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/pytorch-book)](https://github.com/xinetzone/pytorch-book/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/pytorch-book)](https://github.com/xinetzone/pytorch-book/blob/main/LICENSE) ![repo size](https://img.shields.io/github/repo-size/xinetzone/pytorch-book.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/pytorch-book.svg)](https://github.com/xinetzone/pytorch-book/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/pytorch-book.svg)](https://github.com/xinetzone/pytorch-book/watchers) 

参考大量 [d2l-ai](https://github.com/d2l-ai/d2l-zh) 项目的资源。
